==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BlockChaosFluentImpl<A extends BlockChaosFluent<A>> extends BaseFluent<A> implements BlockChaosFluent<A>{
  public BlockChaosFluentImpl() {
  }
  public BlockChaosFluentImpl(BlockChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private BlockChaosSpecBuilder spec;
  private BlockChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public BlockChaosFluent.MetadataNested<A> withNewMetadata() {
    return new BlockChaosFluentImpl.MetadataNestedImpl();
  }
  public BlockChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new BlockChaosFluentImpl.MetadataNestedImpl(item);
  }
  public BlockChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public BlockChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public BlockChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public BlockChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public BlockChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(BlockChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new BlockChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public BlockChaosFluent.SpecNested<A> withNewSpec() {
    return new BlockChaosFluentImpl.SpecNestedImpl();
  }
  public BlockChaosFluent.SpecNested<A> withNewSpecLike(BlockChaosSpec item) {
    return new BlockChaosFluentImpl.SpecNestedImpl(item);
  }
  public BlockChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public BlockChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new BlockChaosSpecBuilder().build());
  }
  public BlockChaosFluent.SpecNested<A> editOrNewSpecLike(BlockChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public BlockChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public BlockChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(BlockChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new BlockChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public BlockChaosFluent.StatusNested<A> withNewStatus() {
    return new BlockChaosFluentImpl.StatusNestedImpl();
  }
  public BlockChaosFluent.StatusNested<A> withNewStatusLike(BlockChaosStatus item) {
    return new BlockChaosFluentImpl.StatusNestedImpl(item);
  }
  public BlockChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public BlockChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new BlockChaosStatusBuilder().build());
  }
  public BlockChaosFluent.StatusNested<A> editOrNewStatusLike(BlockChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BlockChaosFluentImpl that = (BlockChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<BlockChaosFluent.MetadataNested<N>> implements BlockChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) BlockChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends BlockChaosSpecFluentImpl<BlockChaosFluent.SpecNested<N>> implements BlockChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(BlockChaosSpec item) {
      this.builder = new BlockChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new BlockChaosSpecBuilder(this);
    }
    BlockChaosSpecBuilder builder;
    public N and() {
      return (N) BlockChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends BlockChaosStatusFluentImpl<BlockChaosFluent.StatusNested<N>> implements BlockChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(BlockChaosStatus item) {
      this.builder = new BlockChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new BlockChaosStatusBuilder(this);
    }
    BlockChaosStatusBuilder builder;
    public N and() {
      return (N) BlockChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BlockChaosFluentImpl<A extends BlockChaosFluent<A>> extends BaseFluent<A> implements BlockChaosFluent<A>{
  public BlockChaosFluentImpl() {
  }
  public BlockChaosFluentImpl(BlockChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private BlockChaosSpecBuilder spec;
  private BlockChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public BlockChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new BlockChaosFluentImpl.MetadataNestedImpl();
  }
  public BlockChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new BlockChaosFluentImpl.MetadataNestedImpl(item);
  }
  public BlockChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public BlockChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public BlockChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public BlockChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public BlockChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(BlockChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new BlockChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public BlockChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new BlockChaosFluentImpl.SpecNestedImpl();
  }
  public BlockChaosFluentImpl.SpecNested<A> withNewSpecLike(BlockChaosSpec item) {
    return new BlockChaosFluentImpl.SpecNestedImpl(item);
  }
  public BlockChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public BlockChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new BlockChaosSpecBuilder().build());
  }
  public BlockChaosFluentImpl.SpecNested<A> editOrNewSpecLike(BlockChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public BlockChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public BlockChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(BlockChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new BlockChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public BlockChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new BlockChaosFluentImpl.StatusNestedImpl();
  }
  public BlockChaosFluentImpl.StatusNested<A> withNewStatusLike(BlockChaosStatus item) {
    return new BlockChaosFluentImpl.StatusNestedImpl(item);
  }
  public BlockChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public BlockChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new BlockChaosStatusBuilder().build());
  }
  public BlockChaosFluentImpl.StatusNested<A> editOrNewStatusLike(BlockChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BlockChaosFluentImpl that = (BlockChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<BlockChaosFluentImpl.MetadataNested<N>> implements BlockChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) BlockChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends BlockChaosSpecFluentImpl<BlockChaosFluentImpl.SpecNested<N>> implements BlockChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(BlockChaosSpec item) {
      this.builder = new BlockChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new BlockChaosSpecBuilder(this);
    }
    BlockChaosSpecBuilder builder;
    public N and() {
      return (N) BlockChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends BlockChaosStatusFluentImpl<BlockChaosFluentImpl.StatusNested<N>> implements BlockChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(BlockChaosStatus item) {
      this.builder = new BlockChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new BlockChaosStatusBuilder(this);
    }
    BlockChaosStatusBuilder builder;
    public N and() {
      return (N) BlockChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
